@@ -183,7 +183,7 @@ class Client:
 
     def _put_branch_object(
         self, key: str, scowl: str, branch: Optional[str] = None
-    ) -> str:
+    ) -> None:
         branch = branch or self._branch
         logger.info(f"Putting branch object {key} to branch {branch}")
         query = """
@@ -201,13 +201,16 @@ class Client:
 
     def create_branch_from_scowl(
         self, scowl: str, branch: Optional[str] = None
-    ) -> None:
+    ) -> str:
         """
         Create (or overwrite) branch with single file of scowl source code.
 
         Arguments:
             scowl: Scowl source code as string.
             branch: Specify a source branch other than the client default.
+
+        Returns:
+            Name of branch created
         """
 
         branch = branch or self._branch
@@ -223,15 +226,20 @@ class Client:
         if "error" in b:
             raise Exception(b["error"])
 
+        return b['name']
+
     def create_branch_from_dir(
         self, scowl_dir: Optional[str] = None, branch: Optional[str] = None
-    ) -> None:
+    ) -> str:
         """
         Create (or overwrite) branch with local scowl files.
 
         Arguments:
             scowl_dir: Path to local .scowl files.
             branch: Specify a source branch other than the client default.
+
+        Returns:
+            Name of branch created
         """
         scowl_dir = scowl_dir or CONFIG.scowl_dir
         branch = branch or self._branch
@@ -255,17 +263,18 @@ class Client:
         if "error" in b:
             raise Exception(b["error"])
 
+        return b['name']
+
     def publish_dir(self, scowl_dir: Optional[str] = None) -> None:
         """
-        Create 'main' branch from local scowl dir and promote to LIVE.
+        Push local scowl dir to branch and promote to LIVE.
 
         Arguments:
             scowl_dir: Path to .scowl files. Default: `'.'`
         """
         scowl_dir = scowl_dir or CONFIG.scowl_dir
         logger.info(f"Publishing dir '{scowl_dir}' to LIVE.")
-        branch = "main"
-        self.create_branch_from_dir(scowl_dir, branch)
+        branch = self.create_branch_from_dir(scowl_dir)
         self.publish_branch(branch)
 
     def publish_branch(self, branch: Optional[str] = None) -> None:
@@ -293,14 +302,13 @@ class Client:
 
     def publish_scowl(self, scowl: str) -> None:
         """
-        Create 'main' branch from scowl source and promote to LIVE.
+        Push local scowl source to branch and promote to LIVE.
 
         Arguments:
             scowl: Scowl source code as string.
         """
         logger.info("Publishing scowl to LIVE.")
-        branch = "main"
-        self.create_branch_from_scowl(scowl, branch)
+        branch = self.create_branch_from_scowl(scowl)
         self.publish_branch(branch)
 
     def diff_branch_with_live(
